package Mentat::Stats;
use strict;
use warnings;

#*******************************************************************************
# DOCUMENTATION SECTION
#*******************************************************************************

=head1 NAME

Mentat::Stats - Short module description

=head1 SYNOPSIS

 use Mentat::Stats;

=head1 DESCRIPTION

Extensive module description

=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=head1 SEE ALSO

perl(1), Parent::Module(3).

=head1 FUNCTION REFERENCE

=over 4

=cut

#*******************************************************************************
# LIBRARY LOADING SECTION
#*******************************************************************************

#-- Perl core modules ---------------------------------------------------------#
use Carp;
use Scalar::Util 'blessed';

#use Data::Dumper; #-+-> DEVEL ONLY <-+-#
#use Smart::Comments; #-+-> DEVEL ONLY <-+-#

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#

#*******************************************************************************
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#*******************************************************************************

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

#*******************************************************************************
# INITIALIZATION AND CLEANUP SECTION
#*******************************************************************************

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION $DEVEL);
    $VERSION = '0.1';
    $DEVEL   = 0;
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

#*******************************************************************************
# IMPLEMENTATION SECTION
#*******************************************************************************

=item new() [PUBLIC ,STATIC]

  Usage     : my $instance = Mentat::Stats->new()
  Purpose   : Create and return reference to the new instance
  Arguments : Same as the the _init() method
  Returns   : Mentat::Stats reference on success, croaks on failure
  Throws    : Croaks, if invoked on object
  Comments  : Internally uses _init() method, subclasses should never overload this method.
  See Also  : _init() method

=cut

sub new
{
    my $class = shift;
    confess "Class method not invoked on class" if blessed($class);
    my $self = bless ({}, $class);
    return $self->_init(@_);
}

#-------------------------------------------------------------------------------
# Private interface
#-------------------------------------------------------------------------------

# _init [PROTECTED]
#
#  Usage     : return $self->_init(@_);
#  Purpose   : Initialize the new Mentat::Stats instance
#  Arguments :
#  Returns   : Mentat::Stats reference
#  Throws    : Croaks, if invoked on class
#  Comments  : This method must never be called directly, it is supposed to be overloaded by subclasses.
#  See Also  :

sub _init
{
    my $self = shift;
    confess "Method needs to be implemented in subclass";
}

# _save_image($$) [PROTECTED]
#
#  Usage     :
#  Purpose   :
#  Arguments :
#  Returns   :
#  Throws    :
#  Comments  :
#  See Also  :

sub _save_image($$$)
{
    my $self    = shift;
    croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;
    my ($filename, $data) = @_;

    open(IMG, ">$filename") or die $!;
    binmode IMG;
    print IMG $data;
    close(IMG);

    Log::Loger->info(__PACKAGE__, "[Stats] Stored graph into file '$filename'");

    return $filename;
}

=pod

=back

=cut

1;
